// ********************************************************************
// %name:  NMASUtils.js %
// %version:  1 %
// %date_modified:  Wed Feb 08 16:56:16 2006 %
// Copyright (c) 2005 Novell, Inc. All Rights Reserved.
// THIS WORK IS AN UNPUBLISHED WORK AND CONTAINS CONFIDENTIAL PROPRIETARY
// AND TRADE SECRET INFORMATION OF NOVELL, INC. ACCESS TO THIS WORK IS
// RESTRICTED TO (I) NOVELL, INC. EMPLOYEES WHO HAVE A NEED TO KNOW HOW
// TO PERFORM TASKS WITHIN THE SCOPE OF THEIR ASSIGNMENTS AND (II)
// ENTITIES OTHER THAN NOVELL, INC. WHO HAVE ENTERED INTO APPROPRIATE
// LICENSE AGREEMENTS. NO PART OF THIS WORK MAY BE USED, PRACTICED,
// PERFORMED COPIED, DISTRIBUTED, REVISED, MODIFIED, TRANSLATED, ABRIDGED,
// CONDENSED, EXPANDED, COLLECTED, COMPILED, LINKED, RECAST, TRANSFORMED
// OR ADAPTED WITHOUT THE PRIOR WRITTEN CONSENT OF NOVELL, INC. ANY USE
// OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD SUBJECT THE
// PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
// ********************************************************************


// Global variables.


function nmasIsValidIPAddress(
   address )
{
   // Check first segment
   var frontIindex    = 0;
   var backIndex       = address.indexOf( "." );

   if ( backIndex == -1 )
   {
      return false;
   }

   if ( !nmasIsValidNumberRange( address.substring( frontIindex, backIndex ), 0, 255 ))
   {
      return false;
   }

   // Check second segment
   frontIindex = backIndex + 1;
   backIndex    = address.indexOf( ".", frontIindex );

   if ( backIndex == -1 )
   {
      return false;
   }

   if ( !nmasIsValidNumberRange( address.substring( frontIindex, backIndex ), 0, 255 ))
   {
      return false;
   }

   // Check third segment
   frontIindex = backIndex + 1;
   backIndex   = address.indexOf( ".", frontIindex );

   if ( backIndex == -1 )
   {
      return false;
   }

   if ( !nmasIsValidNumberRange( address.substring( frontIindex, backIndex ), 0, 255 ))
   {
      return false;
   }

   // Check fourth segment and ensure that it is the last
   frontIindex = backIndex+1;
   backIndex    = address.indexOf( ".", frontIindex );

   if ( backIndex != -1 )
   {
      return false;
   }

   if ( !nmasIsValidNumberRange( address.substring( frontIindex ), 0, 255 ))
   {
      return false;
   }

   // If we have arrived here then the IP address is in a valid format
   return true;
}

function nmasIsValidNumberRange( num, min, max )
{
   // Check for numbers only

   if ( isNaN( parseInt( num )))
   {
      return false;
   }

   // Check range of numbers
   if ( num >= min && num <= max )
   {
      return true;
   }

   return false;
}

function nmasIsValidPort( portNum )
{
   if ( !nmasIsValidNumberRange( portNum, 0, 65535 ))
   {
      return false;
   }

   return true;
}

/*--------------------------------------------------------------- */
/* Return a reference to an element given its name.               */
/*--------------------------------------------------------------- */
function nmasGetElementByName( elementName )
{
   var elementRef = null;

   if ( document.getElementById )
   {
      // If this is a DOM-compliant browser then use the DOM method
      elementRef = document.getElementById( elementName );
   }

   if ( null == elementRef && document.all )
   {
      // Otherwise, if the IE API is supported then use the all[] array
      // to find the element
      elementRef = document.all[ elementName ];
   }

   if ( null == elementRef && document.layers )
   {
      // Else if the Netscape API is supported then use the layers[]
      // array to get the element
      elementRef = document.layers[ elementName ];
   }

   return( elementRef );
}

function nmasGetSelectedRadioButton( elementName )
{
   groupLen = eval("document.forms[0].elements['"+elementName+"'].length");

   for (i=0; i<groupLen; i++)
   {
      var element = eval('document.forms[0].elements["'+elementName+'"]['+i+']');

      if ( element != null && element.checked )
      {
         return element;
      }
   }

   return null;
}

function nmasEnableRadioButton( elementName, enabled )
{
   groupLen = eval("document.forms[0].elements['"+elementName+"'].length");

   for (i=0; i<groupLen; i++)
   {
      var element = eval('document.forms[0].elements["'+elementName+'"]['+i+']');

      if ( element != null )
      {
         element.disabled = enabled ? false : true;
      }
   }
}

function nmasGetElementValue( elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( element == null )
   {
      alert( "Element " + elementName + " cannot be found" );
      return "";
   }

   if ( element.type == "radio" )
   {
      return nmasGetSelectedRadioButton( elementName ).value;
   }

   return element.value;
}

function nmasSetElementValue( elementName, elementValue )
{
   var element = nmasGetElementByName( elementName );

   if ( element == null )
   {
      alert( "Element " + elementName + " cannot be found.  Value '" + elementValue + "' not set" );
      return;
   }

   element.value = elementValue;
}

function nmasIsElementValueEmpty( elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      return element.value == "";
   }

   return false;
}

function nmasClearElementValue( elementName )
{
   nmasSetElementValue( elementName, "" );
}

function nmasIsElementChecked( elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      return element.checked;
   }

   return false;
}

function nmasSetElementChecked( elementName, value )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      element.checked = value;
   }
}

function nmasSetElementFocus( elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      element.focus();
   }
}

function nmasIsOptionSelected( elementName, optionNumber )
{
  var element = nmasGetElementByName( elementName );

   if ( element )
   {
      return element.options[ optionNumber ].selected;
   }

   return false;
}

function nmasIsOptionSelectedByValue( elementName, targetValue )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      for ( var i = 0; i < element.options.length; i++ )
      {
         if ( element.options[ i ].value == targetValue )
         {
            return element.options[ i ].selected;
         }
      }
   }

   return false;
}

function nmasSelectOptionByValue( elementName, targetValue )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      for ( var i = 0; i < element.options.length; i++ )
      {
         if ( element.options[ i ].value == targetValue )
         {
            element.options[ i ].selected = true;
         }
      }
   }
}

function nmasGetOptionCount( elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      return element.options.length;
   }

   return 0;
}

function nmasGetOptionValue( elementName, optionNumber )
{
   var element = nmasGetElementByName( elementName );

   if ( element && optionNumber < element.options.length )
   {
      return element.options[ optionNumber ].value;
   }

   return null;
}

function nmasGetSelectedOptionValue( elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      for ( var i = 0; i < element.options.length; i++ )
      {
         if ( element.options[ i ].selected )
         {
            return element.options[ i ].value;
         }
      }
   }

   return "";
}

function nmasEnableControl( elementName, enabled )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      if ( element.type == "radio" )
      {
         nmasEnableRadioButton( elementName, enabled );
      }
      else
      {
         element.disabled = enabled ? false : true;
      }
   }
}

function nmasIsElementEnabled( elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( element )
   {
      return !element.disabled;
   }

   return false;
}

function nmasRemoveOption( elementName, optionNumber )
{
   var element = nmasGetElementByName( elementName );

   if ( element && optionNumber < element.options.length )
   {
      element.options[ optionNumber ] = null;
   }
}

function nmasSubmitDocumentForm( validateForm )
{
   nmasDisableButtons();

   if ( validateForm && typeof isPageValid == "function" && !isPageValid() )
   {
      return;
   }

   document.forms[0].submit();
}
/*--------------------------------------------------------------- */
/* Format a la printf().                                          */
/*--------------------------------------------------------------- */
function nmasFormatString( str, arg1 )
{
   // skip the 0th argument
   for ( var i = 1; i < arguments.length; i++ )
   {
      var toReplace = "{" + eval( i - 1 ) + "}";
      var start = str.indexOf( toReplace );
      if ( start != -1 )
      {
         var before = str.substring( 0, start );
         var insert = arguments[ i ];
         var after = str.substring( start + toReplace.length, str.length );
         var str = before + insert + after;
      }
      else
      {
         break;
      }
   }
   return str;
}

function nmasIsValidDomainFormat(
   domainString )
{
   var status = true;

   // Look for illegal characters
   if ( domainString.indexOf( "/" ) != -1 )
   {
      status = false;
   }
   else if ( domainString.indexOf( ":" ) != -1 )
   {
      status = false;
   }
   else if ( domainString.indexOf( " " ) != -1 )
   {
      status = false;
   }

   return status;
}

// --------------------------------------------------------------- //
// Scans an element's ancestry to determine if anything containing //
// the element is hidden.                                          //
// --------------------------------------------------------------- //
function nmasIsAncestryVisible(
   eWidget)   // The element to check for ancestry visibility.
{
   var   computedStyle;
   var   eParent;

   eParent = eWidget.parentElement;
   if (null == eParent)
   {
      return true;
   } // if


   // Get the computed style for the widget's parent.
   if (eParent.currentStyle)
       computedStyle = eParent.currentStyle;
   else computedStyle = window.getComputedStyle( eParent, '' );


//alert( eParent.nodeName + ': visibility: ' + computedStyle.visibility );


   // Is this widget hidden?
   if ('hidden' == computedStyle.visibility)
   {
      // Yes!  Return false.
      // debugOut_Always( eParent.id + ":  ancestry hidden" );
      return( false );
   } // if

   else if ('visible' == computedStyle.visibility)
   {
      return true;
   } // else if

   else if ('inherit' == computedStyle.visibility)
   {
      // Since the visibility of this element is 'inherit' we need to
      // check the element's parent.  Recursively call ourselves to
      // see if our parent's ancestory is visible.
      return nmasIsAncestryVisible( eParent );
   } // else if

   else
   {
      // We should never get here.
      alert( 'In nmasIsAncestryVisible(), unknown value for visibility: ' + computedStyle.visibility );
   } // else
} // isAncestryVisible

function nmasShowHideAnElement(
   element,           //
   show,              //
   considerAncestry ) //
{
   considerAncestry = (considerAncestry && (true  == considerAncestry));
   if ((null != element) &&
      ((!considerAncestry) || nmasIsAncestryVisible( element )))
   {
      // debugOut_Always( element.id + ":  " + (show ? "show" : "hide") );
      if (show)
      {
         if ( !considerAncestry )
            element.style.visibility = "visible";
         else
            element.style.visibility = 'inherit';
      }
      else element.style.visibility = "hidden";
   } // if
} // showHideAnElement

function nmasShowHideWindowedWidgets(
   show)   			// true -> Show them.  false -> Hide them.
{
  nmasShowHideWindowedWidgets(show, null);
}

function nmasShowHideWindowedWidgets(
   show,   			// true -> Show them.  false -> Hide them.
   arIgnoreThese)	// elements with these names will not be hidden/shown
{
   var   ae;
   var   c;
   var   i, k;

   // Scan the SELECT widgets...
   ae = document.getElementsByTagName( "SELECT" );
   c  = ae.length;
   for (i = 0; i < c; i += 1)
   {
       var bIgnore = false;
       if (null != arIgnoreThese)
       {
         for (k=0; k<arIgnoreThese.length; k++)
         {
            if (arIgnoreThese[k] == ae[i].name)
            {
               bIgnore = true;
            }
         }
       }
       if (!bIgnore)
       {
        // hide this element
        nmasShowHideAnElement(
           ae[i],   // The element to show/hide.
           show,   // true -> Show.  false -> Hide.
           true );   // true -> Consider ancestry's visibility.
     }
   } // for


   // Do we want to consider hiding the other INPUT widgets?  The only
   // one that causes a problem is the select control.
} // showHideWindowedWidgets


function nmasShowElement(
   elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( null != element )
   {
      if ( element.style.display == "none" )
      {
         element.style.display = "block";
      }
   }
}

function nmasHideElement(
   elementName )
{
   var element = nmasGetElementByName( elementName );

   if ( null != element )
   {
      if ( element.style.display != "none" )
      {
         element.style.display = "none";
      }
   }
}

/*--------------------------------------------------------------- */
/* Functions to move options between two <select>'s               */
/*--------------------------------------------------------------- */

      function nmasMoveOption(elementFrom, elementTo, bFromIsInteresting, elementList, strWarnOnFromEmpty)
      {	// If we have a warning string to display if the "elementFrom" control would
        // be emptied by this operation, then display it and do not empty he control.
         if (null != strWarnOnFromEmpty)
         {
           if (1 == elementFrom.options.length)
           {	// There is only one element in the "from" control.
              alert(strWarnOnFromEmpty);
              return;
           }
         }
         var index = elementFrom.selectedIndex;
         if(index!=-1)
         {
            var option = elementFrom.options[index];
            elementFrom.options[index] = null;

            var length = elementTo.options.length;
            elementTo.options[length] = new Option(option.text, option.value);
         }
         if (bFromIsInteresting)
         {
           nmasUpdateAfterMoveOption(elementFrom, elementList);
         }
         else
         {
           nmasUpdateAfterMoveOption(elementTo, elementList);
         }
      }

      function nmasUpdateAfterMoveOption(element, elementList)
      {
         var list = new Array();
         var options = element.options;
         for(var i=0; i < options.length; i++)
         {
            list[list.length] = options[i].value;
         }
         elementList.value = pack(list);
      }

  function nmasMoveOptionUp(sel, elementList)
  {
     var index = sel.selectedIndex;
     if(index>=0 && index>0)
     {
        var tempVal = sel.options[index].value;
        var tempTxt = sel.options[index].text;

        sel.options[index].value = sel.options[index-1].value;
        sel.options[index].text = sel.options[index-1].text;

        sel.options[index-1].value = tempVal;
        sel.options[index-1].text = tempTxt;

        sel.selectedIndex = index-1;
        nmasUpdateAfterMoveOption(sel, elementList);
        }
  }

  function nmasMoveOptionDown(sel, elementList)
  {
     var index = sel.selectedIndex;
     if(index>=0 && index < sel.length-1)
     {
        var tempVal = sel.options[index].value;
        var tempTxt = sel.options[index].text;

        sel.options[index].value = sel.options[index+1].value;
        sel.options[index].text = sel.options[index+1].text;

        sel.options[index+1].value = tempVal;
        sel.options[index+1].text = tempTxt;

        sel.selectedIndex = index+1;
           nmasUpdateAfterMoveOption(sel, elementList);
     }
  }

function nmasEditObject( distinguishedName )
{
   parent.disableButtons();

   var dnArray = new Array();

   dnArray[ 0 ] = distinguishedName;

   document.forms[0].DNList.value     = pack( dnArray );
   document.forms[0].NextAction.value = "EditObject";
   document.forms[0].submit();
}

function handleFrameAction( strAction )
{
   var result = false;

   if ( strAction == "nextButton"   ||
        strAction == "finishButton" ||
        strAction == "backButton"   ||
        strAction == "closeButton" )
   {
      if ( typeof isPageValid == "function" && !isPageValid() )
      {
         return true;
      }

      parent.disableButtons();

      document.forms[0].Frame_Hidden_PB_Navigation.value = strAction;
      document.forms[0].NextAction.value                 = "HandleNavigation";
      document.forms[0].submit();

      result = true;
   }
   else if ( strAction == "backButton2" )
   {
      parent.disableButtons();
      history.go(-1);

      result = true;
   }

   return result;
}

var oldButtons = null;

window.nextButton   = 1;
window.backButton   = 2;
window.applyButton  = 4;
window.cancelButton = 8;
window.finishButton = 16;
window.closeButton  = 32;
window.okButton     = 64;

window.nextDisabledButton   = 128;
window.backDisabledButton   = 256;
window.applyDisabledButton  = 512;
window.cancelDisabledButton = 1024;
window.finishDisabledButton = 2048;
window.closeDisabledButton  = 4096;
window.okDisabledButton     = 8192;

      function setHeader(title, subtitle, helpfile)
      {
         window.helpfile = helpfile;
         wizardHeader.document.getElementById("title").innerHTML = title;
         wizardHeader.document.getElementById("subtitle").innerHTML = subtitle;
         wizardHeader.document.getElementById("helpimage").style.display = (helpfile?"inline":"none");
      }

function nmasSetFooterButtons(buttons)
{
   if ( oldButtons != buttons )
   {
      nmasSetButton( "applyButton",  buttons & applyButton  );
      nmasSetButton( "backButton",   buttons & backButton   );
      nmasSetButton( "nextButton",   buttons & nextButton   );
      nmasSetButton( "cancelButton", buttons & cancelButton );
      nmasSetButton( "finishButton", buttons & finishButton );
      nmasSetButton( "closeButton",  buttons & closeButton  );
      nmasSetButton( "okButton",     buttons & okButton     );

      nmasSetButton( "applyDisabledButton",  buttons & applyDisabledButton  );
      nmasSetButton( "backDisabledButton",   buttons & backDisabledButton   );
      nmasSetButton( "nextDisabledButton",   buttons & nextDisabledButton   );
      nmasSetButton( "cancelDisabledButton", buttons & cancelDisabledButton );
      nmasSetButton( "finishDisabledButton", buttons & finishDisabledButton );
      nmasSetButton( "closeDisabledButton",  buttons & closeDisabledButton  );
      nmasSetButton( "okDisabledButton",     buttons & okDisabledButton     );

      oldButtons = buttons;
   }
}

function nmasSetButton( buttonName, bDisplay )
{
   var button = nmasGetElementByName( buttonName );

   if ( null != button )
   {
      button.style.display = ( bDisplay > 0 ? "inline" : "none" );
   }
}

function nmasDisableButtons()
{
   nmasSetFooterButtons(( oldButtons << 7 ) | ( oldButtons & 16256 ));
}

function nmasDoAction( strAction )
{
   if ( typeof handleAction == "function" && handleAction( strAction ))
   {
      return;
   }

   nmasSetElementValue( "Frame_Hidden_PB_Navigation", strAction );

   if ( strAction == "nextButton"   ||
        strAction == "backButton"   ||
        strAction == "finishButton" ||
        strAction == "applyButton"  ||
        strAction == "okButton" )
   {
      if ( typeof isPageValid == "function" && !isPageValid() )
      {
         return true;
      }
   }

   nmasSetElementValue( "Frame_Hidden_PB_Navigation", strAction );
   nmasSetElementValue( "TaskAction", "Navigate" );

   nmasSubmitDocumentForm();
}

function nmasGetPBClicked()
{
   return nmasGetElementValue( "Frame_Hidden_PB_Navigation" );
}

function showHelpWindow()
{
   launchHelp(window.helpfile);
}

function nmasMoveToUILevel( level )
{
   nmasSetElementValue( "Frame_Hidden_PB_Navigation", "breadCrumb" );
   nmasSetElementValue( "TaskAction", "Navigate" );
   nmasSetElementValue( "TaskParam", level );

   nmasSubmitDocumentForm();
}

function nmasPositionFooterDiv( headerDivID, bodyDivID, footerDivID )
{
   var headerDiv = document.getElementById( headerDivID );
   var bodyDiv   = document.getElementById( bodyDivID   );
   var footerDiv = document.getElementById( footerDivID );

   var screenHeight;
   var screenWidth;

   //get the height and width
   if ( window.innerHeight )
   {
      screenHeight = window.innerHeight;
      screenWidth  = window.innerWidth;
   }
   else if ( document.documentElement && document.documentElement.clientHeight )
   {
      screenHeight = window.innerHeight;
      screenWidth = window.innerWidth;
   }
   else if ( document.body && document.body.clientHeight )
   {
      screenHeight = document.body.clientHeight;
      screenWidth = document.body.clientWidth;
   }
   else
   {
      screenHeight = 0;
      screenWidth = 0;
   }

   var footerHeight = parseInt( footerDiv.style.height, 10 );

   yPos = screenHeight - footerHeight;

   if ( yPos < 0 )
   {
      yPos = 0;
   }

//   var bodyTop  = parseInt( bodyDiv.style.top,  10 );
   var bodyTop  = bodyDiv.offsetTop;
//   var bodyLeft = parseInt( bodyDiv.style.left, 10 );
   var bodyLeft = bodyDiv.offsetLeft;

   if ( isNaN( bodyTop ))
   {
      bodyTop  = bodyDiv.pageY;
      bodyLeft = bodyDiv.pageX;
   }

   if ( isNaN( bodyTop ))
   {
      // See if we can get the header height
      var headerHeight = headerDiv.offsetHeight;

      if ( isNaN( headerHeight ))
      {
         bodyTop = 0;
      }
      else
      {
         bodyTop = headerHeight;
      }
   }

   if ( isNaN( bodyLeft ))
   {
      bodyLeft = 0;
   }

   height = screenHeight - footerHeight - bodyTop;
   width  = screenWidth  - 25;

//   alert( "screenHeight: " + screenHeight + ", footerHeight: " + footerHeight + ", bodyTop: " + bodyTop + ", height: " + height );
   headerDiv.style.width = width  + "px";

   bodyDiv.style.height  = height + "px";
   bodyDiv.style.width   = width  + "px";

   footerDiv.style.top   = yPos  + "px";
   footerDiv.style.width = width + "px";
}

function nmasShowSubMenu(
   event,
   subMenuName )
{
   var element = nmasGetElementByName( subMenuName );

   if ( null != element )
   {
      if ( element.style.display == "none" )
      {
         var source = (event.target ? event.target : event.srcElement);

         element.style.left = source.offsetLeft;

         element.style.display = "block";
      }
   }
}

function nmasHideSubMenu(
   subMenuName )
{
   var element = nmasGetElementByName( subMenuName );

   if ( null != element )
   {
      if ( element.style.display != "none" )
      {
         element.style.display = "none";
      }
   }
}

function nmasShowHelp( helpURL )
{
   runHelp( helpURL );
}

function nmasUpdateWizardSubHeader( subTitle )
{
   nmasGetElementByName("WizardSubHeader").innerHTML = subTitle;
}

function nmasUpdateWizardHeader( title )
{
   nmasGetElementByName("WizardHeader").innerHTML = title;
}

                    // * * * * * * //

                    // End of File //

                    // * * * * * * //



